==> core-react-0.8.0.tgz: package/es/Tabs/TabPanel.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ReactDOM from 'react-dom';
import invariant from 'invariant';
import classlist from 'classlist';

var TabPanel = /*#__PURE__*/function (_React$Component) {
  _inherits(TabPanel, _React$Component);

  function TabPanel() {
    _classCallCheck(this, TabPanel);

    return _possibleConstructorReturn(this, _getPrototypeOf(TabPanel).apply(this, arguments));
  }

  _createClass(TabPanel, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.prepareIsActive(this.props);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.rootNode = ReactDOM.findDOMNode(this);

      if (this.active) {
        this.rootNode.style.display = 'block';

        if (!this.context.tabs.isInit) {// this.rootNode.offsetWidth
        }

        classlist(this.rootNode).add(TabPanel.activeClassName);
      }
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps) {
      this.prevActive = this.active;
      this.prepareIsActive(nextProps);
      return this.active || this.prevActive !== this.active;
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      if (this.active) {
        this.rootNode.style.display = 'block'; // this.rootNode.offsetWidth

        classlist(this.rootNode).add(TabPanel.activeClassName);
      } else {
        this.rootNode.style.display = 'none';
        classlist(this.rootNode).remove(TabPanel.activeClassName);
      }
    }
  }, {
    key: "prepareIsActive",
    value: function prepareIsActive(props) {
      var tabs = this.context.tabs;

      if ('activeKey' in props) {
        this.active = props.activeKey === tabs.props.activeKey;
      } else {
        var index = tabs.panelCount++;
        this.active = index === tabs.state.activeIndex;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          activeKey = _this$props.activeKey,
          other = _objectWithoutProperties(_this$props, ["children", "className", "activeKey"]);

      var tabs = this.context.tabs;
      'activeKey' in tabs.props && invariant('activeKey' in this.props, 'You set `activeKey` for `Tabs` but no `activeKey` for `TabPanel`'); // Should not render and unmount when not acitve

      if (this.active) {
        this.children = children;
      }

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-tabs__panel"), className)
      }, other), this.active ? children : this.children);
    }
  }]);

  return TabPanel;
}(React.Component);

_defineProperty(TabPanel, "activeClassName", "".concat("waui", "-tabs__panel_active"));

TabPanel.contextTypes = {
  tabs: PropTypes.object
};
TabPanel.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** Corresponds to the Tabs `activeKey` */
  activeKey: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};
export default TabPanel;

==> core-react-0.8.2.tgz: package/es/Tabs/TabPanel.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import ReactDOM from 'react-dom';
import invariant from 'invariant';
import classlist from 'classlist';

var TabPanel = /*#__PURE__*/function (_React$Component) {
  _inherits(TabPanel, _React$Component);

  function TabPanel() {
    _classCallCheck(this, TabPanel);

    return _possibleConstructorReturn(this, _getPrototypeOf(TabPanel).apply(this, arguments));
  }

  _createClass(TabPanel, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      this.prepareIsActive(this.props);
    }
  }, {
    key: "componentDidMount",
    value: function componentDidMount() {
      this.rootNode = ReactDOM.findDOMNode(this);

      if (this.active) {
        this.rootNode.style.display = 'block';

        if (!this.context.tabs.isInit) {// this.rootNode.offsetWidth
        }

        classlist(this.rootNode).add(TabPanel.activeClassName);
      }
    }
  }, {
    key: "shouldComponentUpdate",
    value: function shouldComponentUpdate(nextProps) {
      this.prevActive = this.active;
      this.prepareIsActive(nextProps);
      return this.active || this.prevActive !== this.active;
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate() {
      if (this.active) {
        this.rootNode.style.display = 'block'; // this.rootNode.offsetWidth

        classlist(this.rootNode).add(TabPanel.activeClassName);
      } else {
        this.rootNode.style.display = 'none';
        classlist(this.rootNode).remove(TabPanel.activeClassName);
      }
    }
  }, {
    key: "prepareIsActive",
    value: function prepareIsActive(props) {
      var tabs = this.context.tabs;

      if ('activeKey' in props) {
        this.active = props.activeKey === tabs.props.activeKey;
      } else {
        var index = tabs.panelCount++;
        this.active = index === tabs.state.activeIndex;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          activeKey = _this$props.activeKey,
          other = _objectWithoutProperties(_this$props, ["children", "className", "activeKey"]);

      var tabs = this.context.tabs;
      'activeKey' in tabs.props && invariant('activeKey' in this.props, 'You set `activeKey` for `Tabs` but no `activeKey` for `TabPanel`'); // Should not render and unmount when not acitve

      if (this.active) {
        this.children = children;
      }

      return (/*#__PURE__*/React.createElement("div", _extends({
          className: cx("".concat("waui", "-tabs__panel"), className)
        }, other), this.active ? children : this.children)
      );
    }
  }]);

  return TabPanel;
}(React.Component);

_defineProperty(TabPanel, "activeClassName", "".concat("waui", "-tabs__panel_active"));

TabPanel.contextTypes = {
  tabs: PropTypes.object
};
TabPanel.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** Corresponds to the Tabs `activeKey` */
  activeKey: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
};
export default TabPanel;
